@@ -24,14 +24,19 @@ struct _GnomeDbEntryPrivate {
 	gint           col;
 };
 
+static void gnome_db_entry_class_init (GnomeDbEntryClass *klass);
+static void gnome_db_entry_init       (GnomeDbEntry *entry);
+static void gnome_db_entry_destroy    (GtkObject *object);
+
 /*
  * Callbacks
  */
 static void
-row_changed_cb (GdaRecordset *rs, GnomeDbEntry *entry) {
+row_changed_cb (GdaRecordset *rs, GnomeDbEntry *entry)
+{
 	GdaField* field;
 	
-	g_return_if_fail(IS_GDA_RECORDSET(rs));
+	g_return_if_fail(GDA_IS_RECORDSET(rs));
 	g_return_if_fail(GNOME_DB_IS_ENTRY(entry));
 	g_return_if_fail(entry->priv->recset == rs);
 	
@@ -45,29 +50,39 @@ row_changed_cb (GdaRecordset *rs, GnomeDbEntry *entry) {
  * Private functions
  */
 static void
-_gnome_db_entry_destroy (GnomeDbEntry *entry, gpointer user_data) {
+gnome_db_entry_destroy (GtkObject *object)
+{
+	GtkObjectClass *parent_class;
+	GnomeDbEntry *entry = (GnomeDbEntry *) object;
+
 	g_return_if_fail(GNOME_DB_IS_ENTRY(entry));
 	
 	if (entry->priv) {
-		if (IS_GDA_RECORDSET(entry->priv->recset))
-			gtk_object_unref(GTK_OBJECT(entry->priv->recset));
+		if (GDA_IS_RECORDSET(entry->priv->recset))
+			gda_recordset_free (entry->priv->recset);
 		g_free((gpointer) entry->priv);
+		entry->priv = NULL;
 	}
+
+	parent_class = gtk_type_class (gtk_entry_get_type ());
+	if (parent_class && parent_class->destroy)
+		parent_class->destroy (object);
 }
 
 static void
-_gnome_db_entry_class_init (GnomeDbEntryClass *klass) {
+gnome_db_entry_class_init (GnomeDbEntryClass *klass)
+{
+	GtkObjectClass *object_class;
+
+	object_class->destroy = gnome_db_entry_destroy;
 }
 
 static void
-_gnome_db_entry_init (GnomeDbEntry *entry) {
+gnome_db_entry_init (GnomeDbEntry *entry)
+{
 	g_return_if_fail(GNOME_DB_IS_ENTRY(entry));
 	
 	entry->priv = g_new0(GnomeDbEntryPrivate, 1);
-	gtk_signal_connect(GTK_OBJECT(entry),
-	                   "destroy",
-	                   GTK_SIGNAL_FUNC(_gnome_db_entry_destroy),
-	                   NULL);
 }
 
 /*
@@ -82,8 +97,8 @@ gnome_db_entry_get_type (void) {
 			"GnomeDbEntry",
 			sizeof (GnomeDbEntry),
 			sizeof (GnomeDbEntryClass),
-			(GtkClassInitFunc) _gnome_db_entry_class_init,
-			(GtkObjectInitFunc) _gnome_db_entry_init,
+			(GtkClassInitFunc) gnome_db_entry_class_init,
+			(GtkObjectInitFunc) gnome_db_entry_init,
 			(GtkArgSetFunc) NULL,
 			(GtkArgGetFunc) NULL
 		};
@@ -96,11 +111,12 @@ gnome_db_entry_get_type (void) {
  * gnome_db_entry_new
  */
 GtkWidget *
-gnome_db_entry_new (GdaRecordset *recset, gint col) {
+gnome_db_entry_new (GdaRecordset *recset, gint col)
+{
 	GnomeDbEntry* entry;
 	
 	entry = GNOME_DB_ENTRY(gtk_type_new(gnome_db_entry_get_type()));
-	if (IS_GDA_RECORDSET(recset))
+	if (GDA_IS_RECORDSET(recset))
 		gnome_db_entry_set_recordset(entry, recset, col);
 	return GTK_WIDGET(entry);
 }
@@ -109,7 +125,8 @@ gnome_db_entry_new (GdaRecordset *recset, gint col) {
  * gnome_db_entry_get_recordset
  */
 GdaRecordset *
-gnome_db_entry_get_recordset (GnomeDbEntry *entry) {
+gnome_db_entry_get_recordset (GnomeDbEntry *entry)
+{
 	g_return_val_if_fail(GNOME_DB_IS_ENTRY(entry), NULL);
 	g_return_val_if_fail(entry->priv != NULL, NULL);
 	return entry->priv->recset;
@@ -119,18 +136,20 @@ gnome_db_entry_get_recordset (GnomeDbEntry *entry) {
  * gnome_db_entry_set_recordset
  */
 void
-gnome_db_entry_set_recordset (GnomeDbEntry *entry, GdaRecordset *recset, gint col) {
+gnome_db_entry_set_recordset (GnomeDbEntry *entry, GdaRecordset *recset, gint col)
+{
 	g_return_if_fail(GNOME_DB_IS_ENTRY(entry));
 	g_return_if_fail(entry->priv != NULL);
 	
 	/* remove the currently active recordset */
-	if (IS_GDA_RECORDSET(entry->priv->recset)) {
+	if (GDA_IS_RECORDSET(entry->priv->recset)) {
 		gtk_signal_disconnect(GTK_OBJECT(entry->priv->recset),
 		                      gtk_signal_lookup("row_changed", gda_recordset_get_type()));
-		gtk_object_unref(GTK_OBJECT(entry->priv->recset));
+		gda_recordset_free (entry->priv->recset);
 	}
 	
 	/* set the new recordset */
+	gtk_object_ref (GTK_OBJECT (recset));
 	entry->priv->recset = recset;
 	entry->priv->col = col;
 	gtk_signal_connect(GTK_OBJECT(entry->priv->recset),
@@ -144,7 +163,8 @@ gnome_db_entry_set_recordset (GnomeDbEntry *entry, GdaRecordset *recset, gint co
  * gnome_db_entry_get_text
  */
 const gchar *
-gnome_db_entry_get_text (GnomeDbEntry *entry) {
+gnome_db_entry_get_text (GnomeDbEntry *entry)
+{
 	g_return_val_if_fail(GNOME_DB_IS_ENTRY(entry), NULL);
 	return (const gchar *) gtk_entry_get_text(GTK_ENTRY(entry));
 }
@@ -153,5 +173,6 @@ gnome_db_entry_get_text (GnomeDbEntry *entry) {
  * gnome_db_entry_set_text
  */
 void
-gnome_db_entry_set_text (GnomeDbEntry *entry, const gchar *txt) {
+gnome_db_entry_set_text (GnomeDbEntry *entry, const gchar *txt)
+{
 }
