@@ -88,7 +88,7 @@ void           gnome_db_grid_show_row_numbers      (GnomeDbGrid *grid);
 
 #define        gnome_db_grid_get_row_count(grid)   (GNOME_DB_GRID(grid)->total_rows)
 void           gnome_db_grid_clear                 (GnomeDbGrid *grid);
-void           gnome_db_grid_refresh               (GnomeDbGrid *grid);
+//void           gnome_db_grid_refresh               (GnomeDbGrid *grid);
 GdaRecordset*  gnome_db_grid_get_recordset         (GnomeDbGrid *grid);
 void           gnome_db_grid_set_recordset         (GnomeDbGrid *grid,
                                                     GdaRecordset *recset);
